@@ -87,14 +87,9 @@ class Hdf5MemoryMapped(DatasetMemoryMapped):
             self.file_map[self.path] = file
         self.h5file = h5py.File(file, "r+" if self.write else "r")
 
-
-    @classmethod
-    def decode(cls, encoding, spec):
-        ds = cls(**spec)
-        return ds
-
     def __getstate__(self):
-        return {'group': self.group, **super().__getstate__()}
+        state = {'group': self.group, **super().__getstate__()}
+        return state
 
     def __setstate__(self, state):
         self.group = state.pop('group')
@@ -332,7 +327,7 @@ class Hdf5MemoryMapped(DatasetMemoryMapped):
                     if isinstance(values, vaex.column.Column):
                         encoded = vaex.column.ColumnArrowDictionaryEncoded(index, values)
                     else:
-                        encoded = pa.DictionaryArray.from_arrays(index, values)
+                        encoded = pa.DictionaryArray.from_arrays(index, values, safe=False)
                     self.add_column(group_name, encoded)
                 else:
                     raise TypeError(f'Unexpected type {type!r} in {group_name}')
